﻿
local SpeakinSpell = LibStub("AceAddon-3.0"):GetAddon("SpeakinSpell")
local L	= LibStub("AceLocale-3.0"):GetLocale("SpeakinSpell", false)

SpeakinSpell:PrintLoading("SpeakinSpell.lua")

-------------------------------------------------------------------------------
-- GENERAL INITIALIZATION AND MAIN ENTRY POINTS
-------------------------------------------------------------------------------


function SpeakinSpell:ResetToDefaults(FrameName) --TODOFUTURE: reset only the current frame's defaults (optionally)
	SpeakinSpellSavedData.EventTable = nil
	
	-- update/reset runtime data state
	self:InitRuntimeData()
	
	-- copy defaults into current settings using class-specific defaults
	self:InitDefaultSavedData()
	
	-- if the options GUI is showing right now, we need to refresh it to make it show the new data
	self:RefreshFrame("General")
	self:RefreshFrame("CurrentMessagesGUI")
	self:RefreshFrame("CreateNew")
	self:RefreshFrame("RandomSubs")
	
	self:Print(L["Default settings restored"])
end




function SpeakinSpell:OnInitialize()
	local funcname = "OnInitialize"
	self:DebugMsg(funcname, "starting")

    -- Called when the addon is loaded

	self:RegisterAllEvents() -- includes registering for VARIABLES_LOADED event -> OnVariablesLoaded
	self:RegisterChatCommands()	-- register chat commands
	
	-- NOTE: the rest of the initialization does not occur until OnVariablesLoaded below
	
	self:DebugMsg(funcname, "done")
end

-- after OnInitialize, the main initialization waits until the saved variables areloaded
function SpeakinSpell:OnVariablesLoaded()
	local funcname = "OnVariablesLoaded"
	self:DebugMsg(funcname, "starting")

	-- set up runtime data that we don't save, or reset it to defaults
	-- any saved data that directly generates runtime data will be repaired in ValidateAllSavedData
	self:InitRuntimeData()
	
	-- SpeakinSpellSavedData will always exist
	-- SpeakinSpellSavedData.EventTable only exists if actual data has been loaded
	-- NOTE: SpeakinSpellSavedData.EventTable may be empty, but its parent table SpeakinSpellSavedData never will be
	if	SpeakinSpellSavedData.EventTable or -- current name
		SpeakinSpellSavedData.SpellTable then --old name from v3.1.2.04 and earlier
		-- If the format of the saved data has changed due to upgrading to a newer version
		-- then fix the old saved data for compatibility
		self:ValidateAllSavedData()
	else
		self:DebugMsg(funcname, "EventTable does not exist, using defaults")
		-- new user: load defaults
		self:InitDefaultSavedData() --also calls ValidateAllSavedData
	end	

	-- set up the Options GUI config
	-- NOTE: we want to have the Saved Data before we do this
	self:CreateGUI()
	
	-- done loading
	if SpeakinSpellSavedData.ShowVersionAtLogin then
		self:Print( string.format(L["Loaded version %s"], self.CURRENT_VERSION) )
	end

	-- trigger a Login event which can be spoken
	-- this can be used for random messages
	self:DebugMsg(funcname, "Signal System Event: SpeakinSpell Loaded")
	local DetectedEventStub = {
		name = L.EVENTNAMES["SpeakinSpell Loaded"],
		type = "EVENT",
		-- treat these special events as cast by the player on himself
		caster = UnitName("player"),
		target = UnitName("player"),
	}
	self:OnSpeechEvent( DetectedEventStub ) 
	
	-- if FixOldSavedData wants the user to review the updated data
	-- show the requested options frame now
	if self.ShowSettingsPageOnLoad then
		InterfaceOptionsFrame_OpenToCategory(self.ShowSettingsPageOnLoad)
		self.ShowSettingsPageOnLoad = nil
	end

	self:DebugMsg(funcname, "done")
end


function SpeakinSpell:OnEnable()
	-- Called when the addon is enabled
	-- self:RegisterAllEvents() -- did this OnInitialize
end


function SpeakinSpell:OnDisable()
    -- Called when the addon is disabled
	-- we don't need to do anything here
end

